#include "hmiworks.h"
#include "hmi_options.h"

#define TICKS_PER_SECOND 100
#define MS_PER_TICK      (1000 / TICKS_PER_SECOND)
#define APPLICATION_TITLE "TouchPAD-ICPDAS"

volatile tBoolean g_bFirmwareUpdate = false;
unsigned long g_ulLastClearWatchdog = 0;

void SysTickIntHandler(void)
{
    hmi_LCDIdleUpdate(10); 
    hmi_TimerTrigger();
}

int main(void)
{
    SysCtlClockSet(SYSCTL_SYSDIV_4 | SYSCTL_USE_PLL | SYSCTL_OSC_MAIN | SYSCTL_XTAL_8MHZ);
    SysTickPeriodSet(SysCtlClockGet() / TICKS_PER_SECOND);
    SysTickEnable();
    SysTickIntEnable();

    if ( HMI_STARTUP_DELAY )
        hmi_DelayUS( HMI_STARTUP_DELAY * 1000 );  

    if ( HMI_WDT_ENABLE )  // Enable Watchdog 
         hmi_WdtEnable( HMI_WDT_TIMEOUT );

    for (int i=0; i<3; i++) //protect boot loader, don't remove!
          FlashProtectSet(2048*i, FlashReadOnly);
		  
    SoundInit();
    HMI_INIT(O_LANDSCAPE);

    if ( HMI_WDT_ENABLE )
    {  
       g_ulLastClearWatchdog = hmi_GetTickCount();
       hmi_WdtClear();  // Don't reboot
    }

    if ( HMI_STARTUP_BEEP )
        hmi_Beep();

    _frame0();

    TouchScreenInit();
    TouchScreenCallbackSet(WidgetPointerMessage);
    
    if ( HMI_TOUCH_BEEP )
       hmi_TurnTouchBeep(1);

    if ( HMI_LCD_AUTO_OFF ) 
    {
       hmi_LCDIdleSetTimeout( HMI_LCD_AUTO_OFF * 1000 );
       hmi_LCDIdleSetBeep(HMI_LCD_OFF_BEEP, HMI_LCD_ON_BEEP);
    }

    while(!g_bFirmwareUpdate)
    {
        WidgetMessageQueueProcess();
        
        if ( HMI_WDT_ENABLE )
        {
            if ( hmi_GetTickCount() - g_ulLastClearWatchdog > HMI_WDT_CLEAR )
            {
                g_ulLastClearWatchdog = hmi_GetTickCount();
                hmi_WdtClear();  // Don't reboot
            }
        }
    }

    WidgetMessageQueueProcess();
    SysCtlDelay(SysCtlClockGet() / 6);
    SoftwareUpdateBegin();
    while(1) { }
}



